==> hs-Agda-2.2.10_2.tbz: lib/ghc-7.0.3/cabal/Agda-2.2.10/register.sh <==
#!/bin/sh
echo 'name: Agda
version: 2.2.10
id: Agda-2.2.10-afd85394310d36c6b20cd4e24a3b1480

license: OtherLicense
copyright:
maintainer: Ulf Norell <ulfn@chalmers.se>
stability:
homepage: http://wiki.portal.chalmers.se/agda/
package-url:
description: Agda is a dependently typed functional programming language: It has
             inductive families, which are similar to Haskell'\''s GADTs, but they
             can be indexed by values and not just types. It also has
             parameterised modules, mixfix operators, Unicode characters, and an
             interactive Emacs interface (the type checker can assist in the
             development of your code).
             .
             Agda is also a proof assistant: It is an interactive system for
             writing and checking proofs. Agda is based on intuitionistic type
             theory, a foundational system for constructive mathematics developed
             by the Swedish logician Per Martin-L&#xf6;f. It has many
             similarities with other proof assistants based on dependent types,
             such as Coq, Epigram and NuPRL.
             .
             Note that if you want to use the command-line program (agda), then
             you should also install the Agda-executable package. The Agda
             package includes an Emacs mode for Agda, but you need to set up the
             Emacs mode yourself (for instance by running @agda-mode setup@; see
             the README).
             .
             Note also that this library does not follow the package versioning
             policy, because the library is only intended to be used by the Emacs
             mode and the Agda-executable package.
category: Dependent types
author: Ulf Norell, Nils Anders Danielsson, Catarina Coquand, Makoto Takeyama, Andreas Abel, Darin Morrison...
exposed: True
exposed-modules: Agda.Main Agda.ImpossibleTest
                 Agda.Interaction.BasicOps Agda.Interaction.GhciTop
                 Agda.Compiler.HaskellTypes Agda.Compiler.Epic.AuxAST
                 Agda.Compiler.Epic.Compiler Agda.Compiler.Epic.CompileState
                 Agda.Compiler.Epic.ConstructorIrrelevancy
                 Agda.Compiler.Epic.Erasure Agda.Compiler.Epic.Epic
                 Agda.Compiler.Epic.Forcing Agda.Compiler.Epic.FromAgda
                 Agda.Compiler.Epic.LambdaLift Agda.Compiler.Epic.NatDetection
                 Agda.Compiler.Epic.Primitive Agda.Compiler.MAlonzo.Compiler
                 Agda.Compiler.MAlonzo.Encode Agda.Compiler.MAlonzo.Misc
                 Agda.Compiler.MAlonzo.Pretty Agda.Compiler.MAlonzo.Primitives
                 Agda.Packaging.Config Agda.Packaging.Database Agda.Packaging.Monad
                 Agda.Packaging.Types Agda.Interaction.CommandLine.CommandLine
                 Agda.Interaction.Exceptions Agda.Interaction.FindFile
                 Agda.Interaction.Highlighting.Emacs
                 Agda.Interaction.Highlighting.Generate
                 Agda.Interaction.Highlighting.HTML
                 Agda.Interaction.Highlighting.Precise
                 Agda.Interaction.Highlighting.Range
                 Agda.Interaction.Highlighting.Vim Agda.Interaction.Imports
                 Agda.Interaction.MakeCase Agda.Interaction.Monad
                 Agda.Interaction.Options Agda.Syntax.Abstract.Name
                 Agda.Syntax.Abstract.Pretty Agda.Syntax.Abstract.Views
                 Agda.Syntax.Abstract Agda.Syntax.Common
                 Agda.Syntax.Concrete.Definitions Agda.Syntax.Concrete.Name
                 Agda.Syntax.Concrete.Operators.Parser
                 Agda.Syntax.Concrete.Operators Agda.Syntax.Concrete.Pretty
                 Agda.Syntax.Concrete Agda.Syntax.Fixity Agda.Syntax.Info
                 Agda.Syntax.Internal Agda.Syntax.Internal.Generic
                 Agda.Syntax.Internal.Pattern Agda.Syntax.Literal
                 Agda.Syntax.Notation Agda.Syntax.Parser.Alex
                 Agda.Syntax.Parser.Comments Agda.Syntax.Parser.Layout
                 Agda.Syntax.Parser.LexActions Agda.Syntax.Parser.Lexer
                 Agda.Syntax.Parser.LookAhead Agda.Syntax.Parser.Monad
                 Agda.Syntax.Parser.Parser Agda.Syntax.Parser.StringLiterals
                 Agda.Syntax.Parser.Tokens Agda.Syntax.Parser Agda.Syntax.Position
                 Agda.Syntax.Scope.Base Agda.Syntax.Scope.Monad Agda.Syntax.Strict
                 Agda.Syntax.Translation.AbstractToConcrete
                 Agda.Syntax.Translation.ConcreteToAbstract
                 Agda.Syntax.Translation.InternalToAbstract
                 Agda.Termination.CallGraph Agda.Termination.Lexicographic
                 Agda.Termination.Matrix Agda.Termination.SparseMatrix
                 Agda.Termination.Semiring Agda.Termination.TermCheck
                 Agda.Termination.Termination Agda.Tests Agda.TypeChecker
                 Agda.TypeChecking.Abstract Agda.TypeChecking.CompiledClause
                 Agda.TypeChecking.CompiledClause.Match
                 Agda.TypeChecking.Constraints Agda.TypeChecking.Conversion
                 Agda.TypeChecking.Coverage Agda.TypeChecking.Coverage.Match
                 Agda.TypeChecking.Datatypes Agda.TypeChecking.DisplayForm
                 Agda.TypeChecking.Empty Agda.TypeChecking.EtaContract
                 Agda.TypeChecking.Errors Agda.TypeChecking.Free
                 Agda.TypeChecking.Forcing Agda.TypeChecking.Implicit
                 Agda.TypeChecking.Injectivity Agda.TypeChecking.Level
                 Agda.TypeChecking.MetaVars Agda.TypeChecking.MetaVars.Occurs
                 Agda.TypeChecking.Monad.Base Agda.TypeChecking.Monad.Builtin
                 Agda.TypeChecking.Monad.Closure Agda.TypeChecking.Monad.Constraints
                 Agda.TypeChecking.Monad.Context Agda.TypeChecking.Monad.Debug
                 Agda.TypeChecking.Monad.Env Agda.TypeChecking.Monad.Exception
                 Agda.TypeChecking.Monad.Imports Agda.TypeChecking.Monad.MetaVars
                 Agda.TypeChecking.Monad.Mutual Agda.TypeChecking.Monad.Open
                 Agda.TypeChecking.Monad.Options Agda.TypeChecking.Monad.Signature
                 Agda.TypeChecking.Monad.SizedTypes Agda.TypeChecking.Monad.State
                 Agda.TypeChecking.Monad.Statistics Agda.TypeChecking.Monad.Trace
                 Agda.TypeChecking.Monad Agda.TypeChecking.Patterns.Match
                 Agda.TypeChecking.Polarity Agda.TypeChecking.Positivity
                 Agda.TypeChecking.Pretty Agda.TypeChecking.Primitive
                 Agda.TypeChecking.Quote Agda.TypeChecking.Rebind
                 Agda.TypeChecking.RecordPatterns Agda.TypeChecking.Records
                 Agda.TypeChecking.Reduce Agda.TypeChecking.Rules.Builtin
                 Agda.TypeChecking.Rules.Builtin.Coinduction
                 Agda.TypeChecking.Rules.Data Agda.TypeChecking.Rules.Decl
                 Agda.TypeChecking.Rules.Def Agda.TypeChecking.Rules.LHS
                 Agda.TypeChecking.Rules.LHS.Implicit
                 Agda.TypeChecking.Rules.LHS.Instantiate
                 Agda.TypeChecking.Rules.LHS.Problem
                 Agda.TypeChecking.Rules.LHS.Split Agda.TypeChecking.Rules.LHS.Unify
                 Agda.TypeChecking.Rules.Record Agda.TypeChecking.Rules.Term
                 Agda.TypeChecking.Serialise Agda.TypeChecking.SizedTypes
                 Agda.TypeChecking.Substitute Agda.TypeChecking.Telescope
                 Agda.TypeChecking.Test.Generators Agda.TypeChecking.Tests
                 Agda.TypeChecking.UniversePolymorphism Agda.TypeChecking.With
                 Agda.Utils.Char Agda.Utils.Either Agda.Utils.FileName
                 Agda.Utils.Fresh Agda.Utils.Function Agda.Utils.Generics
                 Agda.Utils.Graph Agda.Utils.Hash Agda.Utils.Impossible
                 Agda.Utils.IO.Binary Agda.Utils.IO.Locale Agda.Utils.IO.UTF8
                 Agda.Utils.List Agda.Utils.Map Agda.Utils.Maybe Agda.Utils.Monad
                 Agda.Utils.Permutation Agda.Utils.Pointer Agda.Utils.Pretty
                 Agda.Utils.QuickCheck Agda.Utils.ReadP Agda.Utils.SemiRing
                 Agda.Utils.Size Agda.Utils.String Agda.Utils.Suffix
                 Agda.Utils.TestHelpers Agda.Utils.Trie Agda.Utils.Tuple
                 Agda.Utils.Unicode Agda.Utils.Warshall Agda.Version Agda.Auto.Auto
                 Agda.Auto.Convert Agda.Auto.Typecheck Agda.Auto.NarrowingSearch
                 Agda.Auto.Syntax Agda.Auto.SearchControl Agda.Auto.CaseSplit
hidden-modules: Paths_Agda
import-dirs: /usr/local/lib/ghc-7.0.3/cabal/Agda-2.2.10
library-dirs: /usr/local/lib/ghc-7.0.3/cabal/Agda-2.2.10
              /usr/local/lib
hs-libraries: HSAgda-2.2.10
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: QuickCheck-2.4.0.1-a8d08ef439b8098c973a472e8b62e755
         array-0.3.0.2-3444ee049e55c8df31a0796287f56a5e
         base-4.3.1.0-63fd52d9e7e39016c91be0baf3543757
         binary-0.5.0.2-e7e7651f76a2589e9dd2d6b265a695e0
         bytestring-0.9.1.10-94a0a1c920aee21a485bdf21fd51b2be
         containers-0.4.0.0-8781485edb2ac0db733a9f9c72e27945
         directory-1.1.0.0-689c0feb497f60ef9b6c9a128fc1997e
         filepath-1.2.0.0-b273467b63dd15270d77af61bc610112
         haskeline-0.6.4.0-2a9d51bd7c5b5817a761b21966ceec49
         haskell-src-exts-1.11.1-4f0e2a6e751e4516d99b2b82abae9cbe
         mtl-2.0.1.0-91f62d81c946aa60137dcc008e554a3a
         old-time-1.0.0.6-64e7d46ef71d3ea7f6d3a651bbb2bcca
         pretty-1.0.1.2-6970e62db724fea03caad23f58dd8f86
         process-1.0.1.5-55dfaccf3a91c4cb8f6284a0bafef198
         syb-0.3-8a51ec8e05a2a260bc0e1bb18be953b0
         xhtml-3000.2.0.1-bd52b50f5fc3fa4f631ceea408412a81
         zlib-0.5.3.1-a78f28b72a90bc6d93acffb0c82dfef3
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.3/cabal/Agda-2.2.10/html/Agda.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.3/cabal/Agda-2.2.10/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-Agda-2.3.0.tbz: lib/ghc-7.0.4/cabal/Agda-2.3.0/register.sh <==
#!/bin/sh
echo 'name: Agda
version: 2.3.0
id: Agda-2.3.0-75d71c4c22d118d706ce1dc8227b403c

license: OtherLicense
copyright:
maintainer: Ulf Norell <ulfn@chalmers.se>
stability:
homepage: http://wiki.portal.chalmers.se/agda/
package-url:
description: Agda is a dependently typed functional programming language: It has
             inductive families, which are similar to Haskell'\''s GADTs, but they
             can be indexed by values and not just types. It also has
             parameterised modules, mixfix operators, Unicode characters, and an
             interactive Emacs interface (the type checker can assist in the
             development of your code).
             .
             Agda is also a proof assistant: It is an interactive system for
             writing and checking proofs. Agda is based on intuitionistic type
             theory, a foundational system for constructive mathematics developed
             by the Swedish logician Per Martin-L&#xf6;f. It has many
             similarities with other proof assistants based on dependent types,
             such as Coq, Epigram and NuPRL.
             .
             Note that if you want to use the command-line program (agda), then
             you should also install the Agda-executable package. The Agda
             package includes an Emacs mode for Agda, but you need to set up the
             Emacs mode yourself (for instance by running @agda-mode setup@; see
             the README).
             .
             Note also that this library does not follow the package versioning
             policy, because the library is only intended to be used by the Emacs
             mode and the Agda-executable package.
category: Dependent types
author: Ulf Norell, Nils Anders Danielsson, Catarina Coquand, Makoto Takeyama, Andreas Abel, Darin Morrison...
exposed: True
exposed-modules: Agda.Main Agda.ImpossibleTest
                 Agda.Interaction.BasicOps Agda.Interaction.GhciTop
                 Agda.Compiler.HaskellTypes Agda.Compiler.Epic.AuxAST
                 Agda.Compiler.Epic.CaseOpts Agda.Compiler.Epic.Compiler
                 Agda.Compiler.Epic.CompileState Agda.Compiler.Epic.Epic
                 Agda.Compiler.Epic.Erasure Agda.Compiler.Epic.ForceConstrs
                 Agda.Compiler.Epic.Forcing Agda.Compiler.Epic.FromAgda
                 Agda.Compiler.Epic.Injection Agda.Compiler.Epic.Interface
                 Agda.Compiler.Epic.NatDetection Agda.Compiler.Epic.Primitive
                 Agda.Compiler.Epic.Smashing Agda.Compiler.Epic.Static
                 Agda.Compiler.JS.Case Agda.Compiler.JS.Compiler
                 Agda.Compiler.JS.Syntax Agda.Compiler.JS.Substitution
                 Agda.Compiler.JS.Parser Agda.Compiler.JS.Pretty
                 Agda.Compiler.MAlonzo.Compiler Agda.Compiler.MAlonzo.Encode
                 Agda.Compiler.MAlonzo.Misc Agda.Compiler.MAlonzo.Pretty
                 Agda.Compiler.MAlonzo.Primitives Agda.Packaging.Config
                 Agda.Packaging.Database Agda.Packaging.Monad Agda.Packaging.Types
                 Agda.Interaction.CommandLine.CommandLine
                 Agda.Interaction.EmacsCommand Agda.Interaction.Exceptions
                 Agda.Interaction.FindFile Agda.Interaction.Highlighting.Dot
                 Agda.Interaction.Highlighting.Emacs
                 Agda.Interaction.Highlighting.Generate
                 Agda.Interaction.Highlighting.HTML
                 Agda.Interaction.Highlighting.Precise
                 Agda.Interaction.Highlighting.Range
                 Agda.Interaction.Highlighting.Vim Agda.Interaction.Imports
                 Agda.Interaction.MakeCase Agda.Interaction.Monad
                 Agda.Interaction.Options Agda.Syntax.Abstract.Name
                 Agda.Syntax.Abstract.Pretty Agda.Syntax.Abstract.Views
                 Agda.Syntax.Abstract Agda.Syntax.Common
                 Agda.Syntax.Concrete.Definitions Agda.Syntax.Concrete.Name
                 Agda.Syntax.Concrete.Operators.Parser
                 Agda.Syntax.Concrete.Operators Agda.Syntax.Concrete.Pretty
                 Agda.Syntax.Concrete Agda.Syntax.Fixity Agda.Syntax.Info
                 Agda.Syntax.Internal Agda.Syntax.Internal.Generic
                 Agda.Syntax.Internal.Pattern Agda.Syntax.Literal
                 Agda.Syntax.Notation Agda.Syntax.Parser.Alex
                 Agda.Syntax.Parser.Comments Agda.Syntax.Parser.Layout
                 Agda.Syntax.Parser.LexActions Agda.Syntax.Parser.Lexer
                 Agda.Syntax.Parser.LookAhead Agda.Syntax.Parser.Monad
                 Agda.Syntax.Parser.Parser Agda.Syntax.Parser.StringLiterals
                 Agda.Syntax.Parser.Tokens Agda.Syntax.Parser Agda.Syntax.Position
                 Agda.Syntax.Scope.Base Agda.Syntax.Scope.Monad Agda.Syntax.Strict
                 Agda.Syntax.Translation.AbstractToConcrete
                 Agda.Syntax.Translation.ConcreteToAbstract
                 Agda.Syntax.Translation.InternalToAbstract
                 Agda.Termination.CallGraph Agda.Termination.Lexicographic
                 Agda.Termination.Matrix Agda.Termination.SparseMatrix
                 Agda.Termination.Semiring Agda.Termination.TermCheck
                 Agda.Termination.Termination Agda.Tests Agda.TypeChecker
                 Agda.TypeChecking.Abstract Agda.TypeChecking.CompiledClause
                 Agda.TypeChecking.CompiledClause.Compile
                 Agda.TypeChecking.CompiledClause.Match
                 Agda.TypeChecking.Constraints Agda.TypeChecking.Conversion
                 Agda.TypeChecking.Coverage Agda.TypeChecking.Coverage.Match
                 Agda.TypeChecking.Datatypes Agda.TypeChecking.DisplayForm
                 Agda.TypeChecking.Eliminators Agda.TypeChecking.Empty
                 Agda.TypeChecking.EtaContract Agda.TypeChecking.Errors
                 Agda.TypeChecking.Free Agda.TypeChecking.Forcing
                 Agda.TypeChecking.Implicit Agda.TypeChecking.Injectivity
                 Agda.TypeChecking.Irrelevance Agda.TypeChecking.Level
                 Agda.TypeChecking.LevelConstraints Agda.TypeChecking.MetaVars
                 Agda.TypeChecking.MetaVars.Mention
                 Agda.TypeChecking.MetaVars.Occurs Agda.TypeChecking.Monad.Base
                 Agda.TypeChecking.Monad.Builtin Agda.TypeChecking.Monad.Closure
                 Agda.TypeChecking.Monad.Constraints Agda.TypeChecking.Monad.Context
                 Agda.TypeChecking.Monad.Debug Agda.TypeChecking.Monad.Env
                 Agda.TypeChecking.Monad.Exception Agda.TypeChecking.Monad.Imports
                 Agda.TypeChecking.Monad.MetaVars Agda.TypeChecking.Monad.Mutual
                 Agda.TypeChecking.Monad.Open Agda.TypeChecking.Monad.Options
                 Agda.TypeChecking.Monad.Signature
                 Agda.TypeChecking.Monad.SizedTypes Agda.TypeChecking.Monad.State
                 Agda.TypeChecking.Monad.Statistics Agda.TypeChecking.Monad.Trace
                 Agda.TypeChecking.Monad Agda.TypeChecking.Patterns.Match
                 Agda.TypeChecking.Polarity Agda.TypeChecking.Positivity
                 Agda.TypeChecking.Pretty Agda.TypeChecking.Primitive
                 Agda.TypeChecking.Quote Agda.TypeChecking.Rebind
                 Agda.TypeChecking.RecordPatterns Agda.TypeChecking.Records
                 Agda.TypeChecking.Reduce Agda.TypeChecking.Rules.Builtin
                 Agda.TypeChecking.Rules.Builtin.Coinduction
                 Agda.TypeChecking.Rules.Data Agda.TypeChecking.Rules.Decl
                 Agda.TypeChecking.Rules.Def Agda.TypeChecking.Rules.LHS
                 Agda.TypeChecking.Rules.LHS.Implicit
                 Agda.TypeChecking.Rules.LHS.Instantiate
                 Agda.TypeChecking.Rules.LHS.Problem
                 Agda.TypeChecking.Rules.LHS.Split Agda.TypeChecking.Rules.LHS.Unify
                 Agda.TypeChecking.Rules.Record Agda.TypeChecking.Rules.Term
                 Agda.TypeChecking.Serialise Agda.TypeChecking.SizedTypes
                 Agda.TypeChecking.Substitute Agda.TypeChecking.Telescope
                 Agda.TypeChecking.Test.Generators Agda.TypeChecking.Tests
                 Agda.TypeChecking.UniversePolymorphism Agda.TypeChecking.With
                 Agda.Utils.VarSet Agda.Utils.Char Agda.Utils.Either
                 Agda.Utils.FileName Agda.Utils.Fresh Agda.Utils.Function
                 Agda.Utils.Generics Agda.Utils.Graph Agda.Utils.Hash
                 Agda.Utils.Impossible Agda.Utils.IO.Binary Agda.Utils.IO.Locale
                 Agda.Utils.IO.UTF8 Agda.Utils.List Agda.Utils.Map Agda.Utils.Maybe
                 Agda.Utils.Monad Agda.Utils.Permutation Agda.Utils.Pointer
                 Agda.Utils.Pretty Agda.Utils.QuickCheck Agda.Utils.ReadP
                 Agda.Utils.SemiRing Agda.Utils.Size Agda.Utils.String
                 Agda.Utils.Suffix Agda.Utils.TestHelpers Agda.Utils.Trie
                 Agda.Utils.Tuple Agda.Utils.Unicode Agda.Utils.Warshall
                 Agda.Version Agda.Auto.Auto Agda.Auto.Convert Agda.Auto.Typecheck
                 Agda.Auto.NarrowingSearch Agda.Auto.Syntax Agda.Auto.SearchControl
                 Agda.Auto.CaseSplit
hidden-modules: Paths_Agda
import-dirs: /usr/local/lib/ghc-7.0.4/cabal/Agda-2.3.0
library-dirs: /usr/local/lib/ghc-7.0.4/cabal/Agda-2.3.0
              /usr/local/lib
hs-libraries: HSAgda-2.3.0
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: QuickCheck-2.4.1.1-81620c45086287337e00722d3a62a354
         array-0.3.0.2-3444ee049e55c8df31a0796287f56a5e
         base-4.3.1.0-c683e1c476645dcbab1b168f8e5a9aeb
         binary-0.5.0.2-e7e7651f76a2589e9dd2d6b265a695e0
         bytestring-0.9.1.10-94a0a1c920aee21a485bdf21fd51b2be
         containers-0.4.0.0-8781485edb2ac0db733a9f9c72e27945
         directory-1.1.0.0-689c0feb497f60ef9b6c9a128fc1997e
         filepath-1.2.0.0-b273467b63dd15270d77af61bc610112
         hashable-1.1.2.2-c43bd88712c9ef99008fd36c4aedbd63
         hashtables-1.0.1.2-c4f4883ba12ccd1fc2d9060b19245731
         haskeline-0.6.4.6-a104598ce516ea4c4f41d8dd94903a3b
         haskell-src-exts-1.11.1-98de2715779707ccccbf7ae578b36d33
         mtl-2.0.1.0-91f62d81c946aa60137dcc008e554a3a
         old-time-1.0.0.6-64e7d46ef71d3ea7f6d3a651bbb2bcca
         pretty-1.0.1.2-6970e62db724fea03caad23f58dd8f86
         process-1.0.1.5-55dfaccf3a91c4cb8f6284a0bafef198
         syb-0.3.3-43363d15978052669a36ccb62324e276
         utf8-string-0.3.7-302d4bf7b407eed8244415d2308048a0
         xhtml-3000.2.0.4-bc02f5ff30699e11c3706887265d49e0
         zlib-0.5.3.1-a78f28b72a90bc6d93acffb0c82dfef3
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.4/cabal/Agda-2.3.0/html/Agda.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.4/cabal/Agda-2.3.0/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
